@@ -48,9 +48,12 @@ class AutoEval:
         ] = None,
         use_n_param: bool = True,
         metrics: MetricTypes = None,
+        counterfactual_transformer: str = "all-MiniLM-L6-v2",
+        counterfactual_sentiment_classifier: str = "vader",
         toxicity_device: str = "cpu",
         neutralize_tokens: str = True,
         max_calls_per_min: Optional[int] = None,
+        _stereotype_classifier_model: str = "wu981526092/Sentence-Level-Stereotype-Detector",
     ) -> None:
         """
         This class calculates all toxicity, stereotype, and counterfactual metrics support by langfair
@@ -79,6 +82,14 @@ class AutoEval:
         metrics : dict or list of str, default option compute all supported metrics.
             Specifies which metrics to evaluate.
 
+        counterfactual_transformer: str, default="all-MiniLM-L6-v2"
+            Specifies which huggingface sentence transformer to use when computing cosine distance. See
+            https://huggingface.co/sentence-transformers?sort_models=likes#models
+            for more information. The recommended sentence transformer is 'all-MiniLM-L6-v2'. User can also specify a local path to a model.
+
+        counterfactual_sentiment_classifier: str, default="vader"
+            Specifies the sentiment classifier to use for counterfactual sentiment bias calculation.
+
         toxicity_device: str or torch.device input or torch.device object, default="cpu"
             Specifies the device that toxicity classifiers use for prediction. Set to "cuda" for classifiers to be able
             to leverage the GPU. Currently, 'detoxify_unbiased' and 'detoxify_original' will use this parameter.
@@ -98,7 +109,10 @@ class AutoEval:
         self.use_n_param = use_n_param
         self.toxicity_device = toxicity_device
         self.neutralize_tokens = neutralize_tokens
+        self._stereotype_classifier_model = _stereotype_classifier_model
         self.results = {"metrics": {}, "data": {}}
+        self.counterfactual_transformer = counterfactual_transformer
+        self.counterfactual_sentiment_classifier = counterfactual_sentiment_classifier
 
         self.cf_generator_object = CounterfactualGenerator(
             langchain_llm=langchain_llm,
@@ -173,11 +187,19 @@ class AutoEval:
                 self.counterfactual_response_metadata = {}
                 for attribute in protected_words.keys():
                     if protected_words[attribute] > 0:
-                        self.counterfactual_responses[
-                            attribute
-                        ] = await self.cf_generator_object.generate_responses(
-                            count=count, prompts=self.prompts, attribute=attribute
-                        )
+                        try:
+                            self.counterfactual_responses[
+                                attribute
+                            ] = await self.cf_generator_object.generate_responses(
+                                count=count, prompts=self.prompts, attribute=attribute
+                            )
+                        except AssertionError as e:
+                            # Handle case where prompts don't contain the specific attribute words
+                            print(
+                                f"Warning: Could not generate counterfactual responses for {attribute}: {e}"
+                            )
+                            # Remove this attribute from protected_words to prevent KeyError later
+                            protected_words[attribute] = 0
         else:
             print(
                 "Fairness through unawareness is satisfied. Toxicity and stereotype assessments will be conducted."
@@ -220,7 +242,9 @@ class AutoEval:
             for attribute in protected_words.keys()
             if protected_words[attribute] > 0
         ]
-        stereotype_object = StereotypeMetrics()
+        stereotype_object = StereotypeMetrics(
+            _classifier_model=self._stereotype_classifier_model
+        )
         stereotype_results = stereotype_object.evaluate(
             prompts=list(self.prompts),
             responses=list(self.responses),
@@ -233,8 +257,8 @@ class AutoEval:
         self.stereotype_scores = stereotype_results["data"]
         del stereotype_results
 
-        # 6. Calculate CF metrics (if FTU not satisfied)
-        if total_protected_words > 0:
+        # 6. Calculate CF metrics (if FTU not satisfied and counterfactual metrics requested)
+        if total_protected_words > 0 and "counterfactual" in self.metrics:
             print("\n\033[1mStep 6: Evaluate Counterfactual Metrics\033[0m")
             print("---------------------------------------")
             print("Evaluating metrics...")
@@ -242,9 +266,14 @@ class AutoEval:
             self.counterfactual_data = {}
             counterfactual_object = CounterfactualMetrics(
                 neutralize_tokens=self.neutralize_tokens,
+                transformer=self.counterfactual_transformer,
+                sentiment_classifier=self.counterfactual_sentiment_classifier,
             )
             for attribute in Protected_Attributes.keys():
-                if protected_words[attribute] > 0:
+                if (
+                    protected_words[attribute] > 0
+                    and attribute in self.counterfactual_responses
+                ):
                     for group1, group2 in combinations(
                         Protected_Attributes[attribute], 2
                     ):
@@ -277,6 +306,8 @@ class AutoEval:
         else:
             print("\n\033[1m(Skipping) Step 6: Evaluate Counterfactual Metrics\033[0m")
             print("--------------------------------------------------")
+            # Initialize empty counterfactual_data when metrics are skipped
+            self.counterfactual_data = {}
 
         if return_data:
             self.results["data"]["Toxicity"] = self.toxicity_data
