@@ -67,6 +67,8 @@ FEMALE_WORDS: List[str] = [
     "girfriend",
     "girlfriends",
     "Mrs.",
+    "gal",
+    "gals",
 ]
 
 MALE_WORDS: List[str] = [
@@ -97,6 +99,8 @@ MALE_WORDS: List[str] = [
     "boyfriend",
     "boyfriends",
     "Mr.",
+    "guy",
+    "guys",
 ]
 
 GENDER_NEUTRAL_WORDS: List[str] = [
@@ -127,6 +131,8 @@ GENDER_NEUTRAL_WORDS: List[str] = [
     "friend",
     "friends",
     "Mx.",
+    "person",
+    "folks",
 ]
 
 GENDER_TO_WORD_LISTS: Dict[str, List[str]] = {
@@ -148,9 +154,7 @@ RACE_WORDS_NOT_REQUIRING_CONTEXT: List[str] = [
     "pacific islander",
     "pacific-islander",
     "latinx",
-    "hispanics",
-    "latinos",
-    "latinas",
+    "hispanic",
     "latino",
     "latina",
     "whites",
@@ -163,35 +167,9 @@ RACE_WORDS_NOT_REQUIRING_CONTEXT: List[str] = [
 
 RACE_WORDS_REQUIRING_CONTEXT: List[str] = [
     "black",
-    "hispanic",
     "white",
-    "asian",
     "indian",
-]
-
-PERSON_WORDS = [
-    "people",
-    "person",
-    "man",
-    "woman",
-    "men",
-    "women",
-    "kid",
-    "kids",
-    "guy",
-    "boy",
-    "girl",
-    "male",
-    "female",
-    "gentleman",
-    "gentlemen",
-    "lady",
-    "ladies",
-    "child",
-    "teenager",
-    "fellow",
-    "baby",
-    "babies",
+    "asian",
 ]
 
 
@@ -944,3 +922,73 @@ PROFESSION_LIST: List[str] = [
     "wrestler",
     "writer",
 ]
+
+
+# --- Used for counterfactual substitution and FTU checking
+OTHER_PERSON_NOUNS: List[str] = [
+    "child",
+    "teenager",
+    "fellow",
+    "baby",
+    "babies",
+    "adult",
+    "member",
+    "human",
+    "acquaintance",
+    "colleague",
+    "neighbor",
+    "stranger",
+    "citizen",
+    "immigrant",
+    "relative",
+    "guest",
+    "visitor",
+]
+
+WORDS_TO_REMOVE: List[str] = [
+    # pronouns
+    "her",
+    "she",
+    "hers",
+    "herself",
+    "he",
+    "his",
+    "him",
+    "himself",
+    # redundant superstrings
+    "daughters",
+    "mothers",
+    "girls",
+    "females",
+    "sisters",
+    "aunts",
+    "nieces",
+    "grandmothers",
+    "girlfriends",
+    "Mrs.",
+    "gals",
+    "sons",
+    "fathers",
+    "boys",
+    "males",
+    "brothers",
+    "uncles",
+    "nephews",
+    "grandfathers",
+    "boyfriends",
+    "guys",
+    # Titles
+    "Mr.",
+    "Mrs.",
+    "Mx.",
+]
+
+
+PERSON_WORDS_LIST = (
+    FEMALE_WORDS
+    + MALE_WORDS
+    + GENDER_NEUTRAL_WORDS
+    + PROFESSION_LIST
+    + OTHER_PERSON_NOUNS
+)
+PERSON_WORDS = list(set(PERSON_WORDS_LIST) - set(WORDS_TO_REMOVE))
